Module blaxel.core.sandbox.client.models.file_with_content
==========================================================

Classes
-------

`FileWithContent(content: str, group: str, last_modified: str, name: str, owner: str, path: str, permissions: str, size: int)`
:   Attributes:
        content (str):
        group (str):
        last_modified (str):
        name (str):
        owner (str):
        path (str):
        permissions (str):
        size (int):
    
    Method generated by attrs for class FileWithContent.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `content: str`
    :

    `group: str`
    :

    `last_modified: str`
    :

    `name: str`
    :

    `owner: str`
    :

    `path: str`
    :

    `permissions: str`
    :

    `size: int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :